"""
Various settings that the application for its running.
"""

active_theme = None
"""Theme that was set by `set_theme` function."""

SUPPORTED_THEMES = [
    "default",
]
"""
Supported names of themes.
"""
